# PyQGen

Author: Giuseppe Lipari
Email : giuseppe.lipari@univ-lille.fr

- A command line script to generate a randomized list of questions taken
from a orgmode file. 
- It uses orgparse to read the orgmode file

TO BE COMPLETED
